@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2014 Ivan Melnikov <iv at altlinux dot org>
 #
 # Author: Joshua Harlow <harlowja@yahoo-inc.com>
@@ -75,6 +73,18 @@ class CheckCarriageReturn(LineCheck):
             yield ('D004', 'Found literal carriage return')
 
 
+class CheckValidity(ContentCheck):
+    REPORTS = frozenset(["D000"])
+
+    def report_iter(self, parsed_file):
+        for error in parsed_file.errors:
+            if error.line is None:
+                continue
+            if error.level <= 1:
+                continue
+            yield (error.line, 'D000', error.message)
+
+
 class CheckMaxLineLength(ContentCheck):
     REPORTS = frozenset(["D001"])
 
